==> graphql-web-lite-16.6.0-2.tgz: package/validation/rules/PossibleFragmentSpreadsRule.js <==
var jsutils_inspect = require("../../jsutils/inspect.js");

var type_definition = require("../../type/definition.js");

var utilities_typeComparators = require("../../utilities/typeComparators.js");

var utilities_typeFromAST = require("../../utilities/typeFromAST.js");

var shared = require("../../shared.js");

exports.PossibleFragmentSpreadsRule = function PossibleFragmentSpreadsRule(context) {
  return {
    InlineFragment(node) {
      const fragType = context.getType();
      const parentType = context.getParentType();
      if (type_definition.isCompositeType(fragType) && type_definition.isCompositeType(parentType) && !utilities_typeComparators.doTypesOverlap(context.getSchema(), fragType, parentType)) {
        const parentTypeStr = jsutils_inspect.inspect(parentType);
        const fragTypeStr = jsutils_inspect.inspect(fragType);
        context.reportError(new shared.GraphQLError(`Fragment cannot be spread here as objects of type "${parentTypeStr}" can never be of type "${fragTypeStr}".`, {
          nodes: node
        }));
      }
    },
    FragmentSpread(node) {
      const fragName = node.name.value;
      const fragType = function getFragmentType(context, name) {
        const frag = context.getFragment(name);
        if (frag) {
          const type = utilities_typeFromAST.typeFromAST(context.getSchema(), frag.typeCondition);
          if (type_definition.isCompositeType(type)) {
            return type;
          }
        }
      }(context, fragName);
      const parentType = context.getParentType();
      if (fragType && parentType && !utilities_typeComparators.doTypesOverlap(context.getSchema(), fragType, parentType)) {
        const parentTypeStr = jsutils_inspect.inspect(parentType);
        const fragTypeStr = jsutils_inspect.inspect(fragType);
        context.reportError(new shared.GraphQLError(`Fragment "${fragName}" cannot be spread here as objects of type "${parentTypeStr}" can never be of type "${fragTypeStr}".`, {
          nodes: node
        }));
      }
    }
  };
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/PossibleFragmentSpreadsRule.js <==
var jsutils_inspect = require("../../jsutils/inspect.js");

var type_definition = require("../../type/definition.js");

var utilities_typeComparators = require("../../utilities/typeComparators.js");

var utilities_typeFromAST = require("../../utilities/typeFromAST.js");

var graphql_web = require("@0no-co/graphql.web");

exports.PossibleFragmentSpreadsRule = function PossibleFragmentSpreadsRule(context) {
  return {
    InlineFragment(node) {
      const fragType = context.getType();
      const parentType = context.getParentType();
      if (type_definition.isCompositeType(fragType) && type_definition.isCompositeType(parentType) && !utilities_typeComparators.doTypesOverlap(context.getSchema(), fragType, parentType)) {
        const parentTypeStr = jsutils_inspect.inspect(parentType);
        const fragTypeStr = jsutils_inspect.inspect(fragType);
        context.reportError(new graphql_web.GraphQLError(`Fragment cannot be spread here as objects of type "${parentTypeStr}" can never be of type "${fragTypeStr}".`, {
          nodes: node
        }));
      }
    },
    FragmentSpread(node) {
      const fragName = node.name.value;
      const fragType = function getFragmentType(context, name) {
        const frag = context.getFragment(name);
        if (frag) {
          const type = utilities_typeFromAST.typeFromAST(context.getSchema(), frag.typeCondition);
          if (type_definition.isCompositeType(type)) {
            return type;
          }
        }
      }(context, fragName);
      const parentType = context.getParentType();
      if (fragType && parentType && !utilities_typeComparators.doTypesOverlap(context.getSchema(), fragType, parentType)) {
        const parentTypeStr = jsutils_inspect.inspect(parentType);
        const fragTypeStr = jsutils_inspect.inspect(fragType);
        context.reportError(new graphql_web.GraphQLError(`Fragment "${fragName}" cannot be spread here as objects of type "${parentTypeStr}" can never be of type "${fragTypeStr}".`, {
          nodes: node
        }));
      }
    }
  };
};
